#########
SuperFreq
#########

.. image:: _static/rick_james.jpg
   :width: 196px
   :align: center
   :target: https://www.youtube.com/watch?v=QYHxGBH6o4M

|
|

A Python package for orbital frequency analysis.

This package implements a version of the Numerical Analysis of Fundamental Frequencies close to that implemented by Monica Valluri in `NAFF <http://dept.astro.lsa.umich.edu/~mvalluri/resources.html>`_, which itself is an implementation of the algorithm first used by Jacques Laskar (see `this review <http://arxiv.org/pdf/math/0305364v3.pdf>`_ and citations within).

The package is developed in
`a public repository on GitHub <https://github.com/adrn/SuperFreq>`_. If you
have any trouble installing, find any bugs, or have any questions, please `open an issue on GitHub <https://github.com/adrn/SuperFreq/issues>`_.

Documentation
=============

.. toctree::
   :maxdepth: 2

   install
   getting-started
   reference-api
